# Copyright 2022-2023 XProbe Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .core import collect_pandas_module_members


def _install():
    from .core import (
        _collect_pandas_dataframe_members,
        _collect_pandas_index_members,
        _collect_pandas_series_members,
    )

    _collect_pandas_dataframe_members()
    _collect_pandas_series_members()
    _collect_pandas_index_members()
